#!/bin/sh
#
# Sets up the Allegro package for building with the specified compiler,
# and if possible converting text files to the desired target format.
#

proc_help()
{
   echo
   echo "Usage: $0 <platform> [--quick|--dtou|--utod]"
   echo
   echo "Where platform is one of: bcc32, beos, djgpp, haiku, mingw, qnx, unix"
   echo "mac, macosx, macosx-universal, psp and watcom."
   echo "The --quick parameter turns off text file conversion, --dtou converts from"
   echo "DOS/Win32 format to Unix, --utod converts from Unix to DOS/Win32 format."
   echo "If no parameter is specified --quick is assumed."
   echo
}

proc_fix()
{
   echo "Configuring Allegro for $1 ..."

   if [ "$2" != "none" ]; then
      echo "# generated by fix.sh" > makefile
      echo "MAKEFILE_INC = $2" >> makefile
      echo "include makefile.all" >> makefile
   fi

   echo "/* generated by fix.sh */" > include/allegro/platform/alplatf.h
   echo "#define $3" >> include/allegro/platform/alplatf.h
}

proc_fix_osx_ub()
{
   echo "Configuring Allegro for Mac OSX Universal Binary ..."

   echo "# generated by fix.sh" > makefile
   echo "UB = 1" >> makefile
   echo "MAKEFILE_INC = makefile.osx" >> makefile
   echo "include makefile.all" >> makefile

   echo "/* generated by fix.sh */" > include/allegro/platform/alplatf.h
   echo "#define ALLEGRO_MACOSX" >> include/allegro/platform/alplatf.h
}

proc_filelist()
{
   # common files. This must not include any shell scripts or batch files.
   AL_FILELIST=`find . -type f "(" ! -path "*/.*" ")" -a "(" \
      -name "*.c" -o -name "*.cfg" -o -name "*.cpp" -o -name "*.def" -o \
      -name "*.h" -o -name "*.hin" -o -name "*.in" -o -name "*.inc" -o \
      -name "*.m" -o -name "*.m4" -o -name "*.mft" -o -name "*.s" -o \
      -name "*.rc" -o -name "*.rh" -o -name "*.spec" -o -name "*.pl" -o \
      -name "*.txt" -o -name "*._tx" -o -name "makefile*" -o \
      -name "*.inl" -o -name "CHANGES" -o \
      -name "AUTHORS" -o -name "THANKS" ")" -a ! -path "*addons*" \
   `

   # touch unix shell scripts?
   if [ "$1" != "omit_sh" ]; then
      AL_FILELIST="$AL_FILELIST `find . -type f -name '*.sh' -o \
         -name 'configure' -a ! -path "*addons*"`"
   fi

   # touch DOS batch files?
   if [ "$1" != "omit_bat" ]; then
      AL_FILELIST="$AL_FILELIST `find . -type f -name '*.bat' -a \
         ! -path "*addons*"`"
   fi
}

proc_utod()
{
   echo "Converting files from Unix to DOS/Win32 ..."
   proc_filelist "omit_sh"
   /bin/sh misc/utod.sh $AL_FILELIST
}

proc_dtou()
{
   echo "Converting files from DOS/Win32 to Unix ..."
   proc_filelist "omit_bat"
   /bin/sh misc/dtou.sh $AL_FILELIST
}

# prepare allegro for the given platform.

case "$1" in
   "bcc32"   ) proc_fix "Windows (BCC32)"   "makefile.bcc" "ALLEGRO_BCC32";;
   "beos"    ) proc_fix "BeOS"              "makefile.be"  "ALLEGRO_BEOS";;
   "djgpp"   ) proc_fix "DOS (djgpp)"       "makefile.dj"  "ALLEGRO_DJGPP";;
   "haiku"   ) proc_fix "Haiku"             "makefile.be"  "ALLEGRO_HAIKU";;
   "mingw"   ) proc_fix "Windows (MinGW)"   "makefile.mgw" "ALLEGRO_MINGW32";;
   "mingw32" ) proc_fix "Windows (MinGW)"   "makefile.mgw" "ALLEGRO_MINGW32";;
   # The 'msvc' target is undocumented in the help message, but is used
   # during the release process by misc/zipup.sh.
   "msvc"    ) proc_fix "Windows (MSVC)"    "makefile.vc"  "ALLEGRO_MSVC";;
   "qnx"     ) proc_fix "QNX"               "makefile.qnx" "ALLEGRO_QNX";;
   "unix"    ) proc_fix "Unix"              "none"         "ALLEGRO_UNIX";;
   "mac"     ) proc_fix "Mac"               "none"         "ALLEGRO_MPW";;
   "macosx"  ) proc_fix "MacOS X"           "makefile.osx" "ALLEGRO_MACOSX";;
   "macosx-universal" ) proc_fix_osx_ub ;;
   "psp"     ) proc_fix "PSP"               "makefile.psp" "ALLEGRO_PSP";;
   "watcom"  ) proc_fix "DOS (Watcom)"      "makefile.wat" "ALLEGRO_WATCOM";;
   "help"    ) proc_help; exit 0;;
   *         ) proc_help; exit 0;;
esac

# convert all text-file line endings.

trap 'exit $?' 1 2 3 13 15

case "$2" in
  "--utod"  ) proc_utod "$1";;
  "--dtou"  ) proc_dtou "$1";;
  "--quick" ) echo "No text file conversion performed ...";;
esac

# set execute permissions just in case.

chmod +x *.sh misc/*.sh tools/x11/*.sh misc/*.pl
if [ -f configure ]; then
   chmod +x configure
fi

# run fix.sh for addons.  We call /bin/sh explicitly in case the fix.sh
# files have lost the execute bit.

if ! ( cd addons/allegrogl && /bin/sh fix.sh $1 $2 )
then
   echo "Error occured while executing AllegroGL's fix.sh!"
fi
if ! ( cd addons/loadpng && /bin/sh fix.sh $1 $2 )
then
   echo "Error occured while executing loadpng's fix.sh!"
fi
if ! ( cd addons/logg && /bin/sh fix.sh $1 $2 )
then
   echo "Error occured while executing logg's fix.sh!"
fi
if ! ( cd addons/jpgalleg && /bin/sh fix.sh $1 $2 )
then
   echo "Error occured while executing jpgalleg's fix.sh!"
fi

echo "Done!"
